@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
- * $Id: BasicSession.java 1174 2004-02-27 23:44:44Z nfiedler $
+ * $Id: BasicSession.java 1353 2004-10-17 01:03:03Z nfiedler $
  *
  ********************************************************************/
 
@@ -168,6 +168,14 @@ public class BasicSession extends AbstractSession implements VMEventListener {
                 getListeners().resumeAll(se);
             }
 
+            // Set the default stratum to the user preference, but only if
+            // the JDI version is 1.4 or higher.
+            VirtualMachine vm = connection.getVM();
+            if (vm.canGetSourceDebugExtension()) {
+                String stratum = preferences().get("defaultStratum", Defaults.STRATUM);
+                connection.getVM().setDefaultStratum(stratum);
+            }
+
             if (showSource) {
                 // Show the source file for the main class.
                 String main = connection.getMainClass();
