@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
- * $Id: BreakpointManager.java 1146 2004-02-20 03:41:14Z nfiedler $
+ * $Id: BreakpointManager.java 1311 2004-09-29 05:18:12Z nfiedler $
  *
  ********************************************************************/
 
@@ -955,6 +955,12 @@ public class BreakpointManager implements Manager, VMEventListener {
 
         // Now remove this group's breakpoints.
         iter = group.breakpoints(false);
+        List tempList = new ArrayList();
+        while (iter.hasNext()) {
+            // Have to use a temporary list to avoid concurrent modification.
+            tempList.add(iter.next());
+        }
+        iter = tempList.iterator();
         while (iter.hasNext()) {
             Breakpoint bp = (Breakpoint) iter.next();
             // Notify the listeners before taking action.
