@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
- * $Id: LocalsPanel.java 1113 2004-01-25 22:25:32Z nfiedler $
+ * $Id: LocalsPanel.java 1345 2004-10-12 07:04:17Z nfiedler $
  *
  ********************************************************************/
 
@@ -48,17 +48,19 @@ import com.sun.jdi.ThreadReference;
 import com.sun.jdi.Type;
 import com.sun.jdi.Value;
 import com.sun.jdi.VMDisconnectedException;
-import java.awt.Color;
-import java.awt.Component;
 import java.awt.Font;
-import java.awt.FontMetrics;
+import java.awt.Color;
+import java.awt.Toolkit;
 import java.awt.Graphics;
+import java.awt.Component;
+import java.awt.FontMetrics;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.ItemEvent;
 import java.awt.event.ItemListener;
 import java.awt.event.MouseEvent;
 import java.awt.event.MouseListener;
+import java.awt.datatransfer.StringSelection;
 import java.io.IOException;
 import java.text.MessageFormat;
 import java.util.ArrayList;
@@ -720,6 +722,10 @@ public class LocalsPanel extends AbstractPanel
         private int mousePositionX;
         /** Y position where mouse was clicked to invoke popup menu. */
         private int mousePositionY;
+        /** Command for show source action. */
+        private static final String SHOWSOURCE_ACTION = "showSource";
+        /** Command for copy action. */
+        private static final String COPY_ACTION = "copy";
 
         /**
          * Constructs the locals panel popup menu.
@@ -746,6 +752,13 @@ public class LocalsPanel extends AbstractPanel
 
             label = Bundle.getString("Locals.menu.showSource");
             JMenuItem item = new JMenuItem(label);
+            item.setActionCommand(SHOWSOURCE_ACTION);
+            add(item);
+            item.addActionListener(this);
+
+            label = Bundle.getString("Locals.copyLabel");
+            item = new JMenuItem(label);
+            item.setActionCommand(COPY_ACTION);
             add(item);
             item.addActionListener(this);
         } // LocalsPopup
@@ -756,45 +769,64 @@ public class LocalsPanel extends AbstractPanel
          * @param  event  an <code>ActionEvent</code> value.
          */
         public void actionPerformed(ActionEvent event) {
-            // Presently only the one menu item.
             TreePath path = localsTree.getPathForLocation(
                 mousePositionX, mousePositionY);
             if (path == null) {
                 return;
             }
-            Variable var = (Variable) path.getLastPathComponent();
-            Value val = var.getValue();
-            PathManager pathman = (PathManager)
-                owningSession.getManager(PathManager.class);
-            SourceSource src = null;
-            if (val instanceof ObjectReference) {
-                ObjectReference or = (ObjectReference) val;
-                try {
-                    src = pathman.mapSource(or.referenceType());
-                } catch (IOException ioe) {
-                    // This case is handled below.
-                }
-            } else {
-                try {
-                    src = pathman.mapSource(var.getTypeName());
-                } catch (IOException ioe) {
-                    // This case is handled below.
-                }
-            }
 
-            if (src != null) {
-                UIAdapter uia = owningSession.getUIAdapter();
-                if (!uia.showFile(src, 0, 0)) {
-                    String msg = MessageFormat.format(
-                        Bundle.getString("couldntOpenFileMsg"),
-                        new Object[] { src.getName() });
-                    owningSession.getUIAdapter().showMessage(
-                        UIAdapter.MESSAGE_ERROR, msg);
+            String action = event.getActionCommand();
+            if (action == SHOWSOURCE_ACTION) {
+                Variable var = (Variable) path.getLastPathComponent();
+                Value val = var.getValue();
+                PathManager pathman = (PathManager)
+                    owningSession.getManager(PathManager.class);
+                SourceSource src = null;
+                if (val instanceof ObjectReference) {
+                    ObjectReference or = (ObjectReference) val;
+                    try {
+                        src = pathman.mapSource(or.referenceType());
+                    } catch (IOException ioe) {
+                        // This case is handled below.
+                    }
+                } else {
+                    try {
+                        src = pathman.mapSource(var.getTypeName());
+                    } catch (IOException ioe) {
+                        // This case is handled below.
+                    }
                 }
-            } else {
-                owningSession.getUIAdapter().showMessage(
-                    UIAdapter.MESSAGE_WARNING,
-                    Bundle.getString("Locals.error.findingSource"));
+
+                if (src != null) {
+                    UIAdapter uia = owningSession.getUIAdapter();
+                    if (!uia.showFile(src, 0, 0)) {
+                        String msg = MessageFormat.format(
+                            Bundle.getString("couldntOpenFileMsg"),
+                            new Object[] { src.getName() });
+                        owningSession.getUIAdapter().showMessage(
+                            UIAdapter.MESSAGE_ERROR, msg);
+                    }
+                } else {
+                    owningSession.getUIAdapter().showMessage(
+                        UIAdapter.MESSAGE_WARNING,
+                        Bundle.getString("Locals.error.findingSource"));
+                }
+
+            } else if (action == COPY_ACTION) {
+                Variable var = (Variable) path.getLastPathComponent();
+                Value val = var.getValue();
+                ContextManager conman = (ContextManager)
+                    owningSession.getManager(ContextManager.class);
+                ThreadReference thread = conman.getCurrentThread();
+                String str = "";
+                try {
+                    str = Variables.printValue(val, thread, "\n");
+                } catch (Exception e) {
+                    str = e.toString();
+                }
+                StringSelection strsel  = new StringSelection(str);
+                Toolkit.getDefaultToolkit().getSystemClipboard().setContents(
+                    strsel, strsel);
             }
         } // actionPerformed
 
